class TicketWorkflowOpDelField(TicketWorkflowOpBase):
    """Resets the defined ticket fields  

    <someaction>.operations = del_field
    <someaction>.del_field = <fieldname>,<fieldname>


    Don't forget to add the `TicketWorkflowOpDelField` to the  workflow
    option in [ticket].
    If there is no workflow option, the line will look like this:

    workflow =  ConfigurableTicketWorkflow,TicketWorkflowOpDelField
    """

    _op_name = 'del_field'

    # ITicketActionController methods

    def render_ticket_action_control(self, req, ticket, action):
        """Returns the action control"""
        fieldslist = ''
        actions = self.get_configurable_workflow().actions
        label = actions[action]['name']
        # check if the field has a value an create output
        for x in self._fields_to_change(action,ticket).values():
            if fieldslist:
                fieldslist = fieldslist + ", %s" % x
            else:
                fieldslist = x

        if fieldslist:
            hint = 'field(s) %s will be cleared' % fieldslist
        else:
            hint = ''
        control = tag('')
        return (label, control, hint)

    def get_ticket_changes(self, req, ticket, action):
        """Returns the change of fields, if needed."""
        field_array = {}

        for field in self._fields_to_change(action,ticket).keys():
            field_array.update({field:''})

        return field_array

    def _fields_to_change(self, action, ticket):
        """Create tuple (field,label) of fields  with content to clear """
        list = {}
        fields = self.config.get('ticket-workflow',
                                action + '.' + self._op_name).strip()
        for field in fields.split(','):
            if ticket[field]:
                label = field
                for x in ticket.fields:
                    if x['name']==field:
                        label = x['label']
                        break
                if list:
                    list.update({field : label})
                else:
                    list = {field : label}

        return list
